@@ -1,3 +1,4 @@
+from django.contrib import admin as django_admin
 from django.contrib.admin.sites import AdminSite
 
 from session_csrf import anonymous_csrf
@@ -14,4 +15,8 @@ class SessionCsrfAdminSite(AdminSite):
 
         return call_parent_login(request, extra_context)
 
+# This is for sites that import this file directly.
 site = SessionCsrfAdminSite()
+
+def monkeypatch():
+    django_admin.site = site
